aboutsummaryrefslogtreecommitdiff
path: root/gcc/tree.h
diff options
context:
space:
mode:
authorRichard Henderson <rth@redhat.com>2002-09-20 00:33:25 -0700
committerRichard Henderson <rth@gcc.gnu.org>2002-09-20 00:33:25 -0700
commit0ee6fdb5f75d25d7488b43dc61ff73872cf406f8 (patch)
treec54a7a01350d6852bd914b86bd519ff2f024d491 /gcc/tree.h
parent42449812831c9db0df90acb0d57ca7a2d4497a90 (diff)
downloadgcc-0ee6fdb5f75d25d7488b43dc61ff73872cf406f8.zip
gcc-0ee6fdb5f75d25d7488b43dc61ff73872cf406f8.tar.gz
gcc-0ee6fdb5f75d25d7488b43dc61ff73872cf406f8.tar.bz2
real.h (enum real_value_class, [...]): Move from real.c.
* real.h (enum real_value_class, SIGNIFICAND_BITS, EXP_BITS, MAX_EXP, SIGSZ, SIG_MSB, struct real_value): Move from real.c. (struct realvaluetype): Remove. (REAL_VALUE_TYPE): Use struct real_value. (REAL_VALUE_TYPE_SIZE): Use SIGNIFICAND_BITS. (test_real_width): New. * real.c: Global replace struct real_value with REAL_VALUE_TYPE. (real_arithmetic): Avoid hoops for REAL_VALUE_TYPE parameters. (real_compare, real_exponent, real_ldexp, real_isinf, real_isnan, real_isneg, real_isnegzero, real_identical, exact_real_inverse, real_to_integer, real_to_integer2, real_to_decimal, real_to_hexadecimal, real_from_string, real_from_integer, real_inf, real_nan, real_2expN, real_convert, real_to_target, real_from_target): Likewise. * tree.h (struct tree_real_cst): Use real_value not realvaluetype. * gengtype-yacc.y (bitfieldopt): Accept an ID as well. From-SVN: r57343
Diffstat (limited to 'gcc/tree.h')
-rw-r--r--gcc/tree.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/tree.h b/gcc/tree.h
index 310d643..c3faa82 100644
--- a/gcc/tree.h
+++ b/gcc/tree.h
@@ -726,10 +726,10 @@ struct tree_int_cst GTY(())
#define TREE_CST_RTL(NODE) (CST_OR_CONSTRUCTOR_CHECK (NODE)->real_cst.rtl)
/* In a REAL_CST node. struct realvaluetype is an opaque entity, with
manipulators defined in real.h. We don't want tree.h depending on
real.h and transitively on tm.h. */
-struct realvaluetype;
+struct real_value;
#define TREE_REAL_CST_PTR(NODE) (REAL_CST_CHECK (NODE)->real_cst.real_cst_ptr)
#define TREE_REAL_CST(NODE) (*TREE_REAL_CST_PTR (NODE))
@@ -738,7 +738,7 @@ struct tree_real_cst GTY(())
{
struct tree_common common;
rtx rtl; /* acts as link to register transfer language (rtl) info */
- struct realvaluetype * real_cst_ptr;
+ struct real_value * real_cst_ptr;
};
/* In a STRING_CST */
@@ -726,10 +726,10 @@ struct tree_int_cst GTY(())
#define TREE_CST_RTL(NODE) (CST_OR_CONSTRUCTOR_CHECK (NODE)->real_cst.rtl)
-/* In a REAL_CST node. struct realvaluetype is an opaque entity, with
+/* In a REAL_CST node. struct real_value is an opaque entity, with
manipulators defined in real.h. We don't want tree.h depending on
real.h and transitively on tm.h. */